/// <reference types="node" />
import { EventEmitter } from "events";
import { Adapter, LoggingTypes } from "./types";
export declare const Colors: {
    Reset: string;
    Bright: string;
    Dim: string;
    Underscore: string;
    Blink: string;
    Reverse: string;
    Hidden: string;
    FgBlack: string;
    FgRed: string;
    FgGreen: string;
    FgYellow: string;
    FgBlue: string;
    FgMagenta: string;
    FgCyan: string;
    FgWhite: string;
    BgBlack: string;
    BgRed: string;
    BgGreen: string;
    BgYellow: string;
    BgBlue: string;
    BgMagenta: string;
    BgCyan: string;
    BgWhite: string;
};
export interface LoggingBaseOptions {
    /**
     * Name will be prefixed on Console output and added to logfiles, if not specified here
     */
    name: string;
    files: boolean | {
        /**
         * Filename/path of the logfile. Skip if generated with name
         */
        logfile: string;
        /**
         * Filename/path of the logfile. Skip if generated with name
         */
        errorfile: string;
    };
    /**
     * Prints output to console
     */
    console: boolean;
}
export declare class LoggingBase {
    private logFile;
    private errorFile;
    private adapter;
    private adapter_init;
    private messageObservable;
    private name;
    constructor(options?: Partial<LoggingBaseOptions> | string);
    addAdapter(adapter: Adapter): void;
    flush(sync: true): void;
    flush(sync: false): Promise<void>;
    waitForSetup(): Promise<void[]>;
    events: EventEmitter;
    debug(...message: any[]): void;
    log(...message: any[]): void;
    warning(...message: any[]): void;
    logWithCustomColors(type: LoggingTypes, colors: string, ...message: any[]): void;
    error(error: Error | string): void;
    errorMessage(...message: any[]): void;
    private message;
}
export declare let Logging: LoggingBase;
export default Logging;
